function y = colnorms(x,p)
%COLNORMS Norms of matrix columns.
%  Y = COLNORMS(X) returns the L2-norms of the columns of X as a row
%  vector.
%
%  Y = COLNORMS(X,p) for p>=0 calculates the Lp-norms.
%
%  See also ROWNORMS, NORMCOLS, NORMROWS.

%  Ron Rubinstein
%  Computer Science Department
%  Technion, Haifa 32000 Israel
%  ronrubin@cs
%
%  April 2005


if (nargin < 2)
  p = 2;
end

if (p<0), error('invalid p-norm specified'); end

if (p==0)
  y = sum(x~=0,1);
  return;
end

if (p==inf)
  y = max(abs(x), [], 1);
  return;
end

y = sum(abs(x).^p,1).^(1/p);